@@ -5,7 +5,7 @@ use blib;
 use DBI;
 
 $dbpath = 'test.gdb';
-$dbh = DBI->connect("dbi:InterBase:database=$dbpath") or die $DBI::errstr;
+$dbh = DBI->connect("dbi:InterBase:database=$dbpath;ib_dialect=3") or die $DBI::errstr;
 
 $cursor = $dbh->prepare("SELECT * FROM SIMPLE ORDER BY PERSON_ID");
 $cursor->execute;
